#!/bin/sh

echo "Snapshotting initial /usr/share/pear contents"
cd /usr/share
tar -c pear > /root/pre.pear.tar
echo "Done.  Press enter to continue."
read

echo "Moving lib/horde to lib/horde_old"
mv ~iworx/lib/horde ~iworx/lib/horde_old
echo "Done.  Press enter to continue."
read

echo "Installing pear.horde.org channel"
pear channel-discover pear.horde.org
echo "Done.  Press enter to continue."
read

echo "Running pear install horde/horde_role"
pear install horde/horde_role
echo "Done.  Press enter to continue."
read

echo "Running pear run-scripts horde/horde_role"
pear run-scripts horde/horde_role
echo "Done.  Press enter to continue."
read

echo "Setting iworx horde install location"
echo /usr/local/interworx/lib/horde | pear run-scripts horde/horde_role
echo "Done.  Press enter to continue."
read

echo "Installing horde, imp, ingo, kronolith, and passwd"
pear install -o -B horde/horde
pear install -o -B horde/imp
pear install -o -B horde/ingo
pear install -o -B horde/passwd
pear install -o -B horde/turba
pear install -o -B horde/kronolith
# kronolith has a tendency to fail the first time for... reasons.
pear install -o -B horde/kronolith
echo "Done.  Press enter to continue."
read

echo "Removing ~iworx/lib/horde/.htaccess"
rm ~iworx/lib/horde/.htaccess
echo "Done.  Press enter to continue."
read

echo "Installing patch binary"
yum -y install patch
echo "Done.  Press enter to continue."
read

echo "Patching lib/horde/lib/core.php to fix include path"
cd ~iworx/
cat <<'EOF' | patch -p1
diff --git b/lib/horde/lib/core.php a/lib/horde/lib/core.php
index 0c76ab1..fbf5984 100644
--- b/lib/horde/lib/core.php
+++ a/lib/horde/lib/core.php
@@ -37,7 +37,9 @@ if (!defined('HORDE_BASE')) {
     define('HORDE_BASE', $dirname . '/..');
 }

-ini_set('include_path', $dirname . PATH_SEPARATOR . ini_get('include_path'));
+set_include_path($dirname . PATH_SEPARATOR . get_include_path());
+ini_set('include_path', '/usr/local/interworx/lib/pear' . PATH_SEPARATOR . ini_get('include_path'));
+
 if (file_exists(HORDE_BASE . '/config/horde.local.php')) {
     include_once HORDE_BASE . '/config/horde.local.php';
 }
EOF
echo "Done.  Press enter to continue."
read

echo "Finding new things in /usr/share/pear since the horde installation, and moving them to ~iworx/lib/pear"
cd /usr/share/pear
find . -type f -mtime 0 | xargs tar rf /root/post.pear.tar
tar rf /root/post.pear.tar Console/
cd ~iworx/lib/pear
tar xf /root/post.pear.tar
echo "Done.  Press enter to continue."
read

echo "Disabling full url calculating - this fixes the mod_proxy issue."
cd ~iworx/
cat <<'EOF' | patch -p1
diff --git b/lib/pear/Horde.php a/lib/pear/Horde.php
index 27007ee..229e8be 100644
--- b/lib/pear/Horde.php
+++ a/lib/pear/Horde.php
@@ -415,6 +415,11 @@ class Horde
             $opts = array();
         }

+        // poehler@interworx added this line to disable "full" url calculating - it breaks interworx's mod_proxy setup
+        // pko
+        // iworx
+        $full = false;
+
         $puri = parse_url($uri);
         /* @todo Fix for PHP < 5.3.6 */
         if (isset($puri['fragment']) && !isset($puri['path'])) {

EOF

echo "Replacing /usr/share/pear/data with /usr/local/interworx/lib/pear/data"
cd ~iworx/lib/pear
find . -type f -exec grep -l /usr/share/pear/data {} \; | xargs -n1 sed -i 's#/usr/share/pear/data#/usr/local/interworx/lib/pear/data#g'
echo "Done.  Press enter to continue."
read

echo "Patching the password salt issue."

cd ~iworx
cat <<'EOF' | patch -p1
diff --git b/lib/pear/Horde/Auth.php a/lib/pear/Horde/Auth.php
index 7027ca8..be112a8 100644
--- b/lib/pear/Horde/Auth.php
+++ a/lib/pear/Horde/Auth.php
@@ -107,8 +107,10 @@ class Horde_Auth
                                               $encryption = 'md5-hex',
                                               $show_encrypt = false)
     {
-        /* Get the salt to use. */
-        $salt = self::getSalt($encryption, $salt, $plaintext);
+        if( $salt == '' ) {
+            /* Get the salt to use. */
+            $salt = self::getSalt($encryption, $salt, $plaintext);
+        }

         /* Encrypt the password. */
         switch ($encryption) {
EOF

echo "Done.  Press enter to continue."
read

echo "Copying conf.php files from horde_old to horde"
cd ~iworx/lib/horde_old/
find . -name 'conf.php' | xargs tar -c | (cd ../horde; tar xv)
echo "Done.  Press enter to continue."
read

cd ~iworx/lib/horde_old/
echo "Copying *.local.* files from horde_old to horde"
find . -name '*.local.*' | xargs tar -c | (cd ../horde; tar xv)
echo "Done.  Press enter to continue."
read

echo "Reinstalling interworx-bin"
yum -y reinstall interworx-bin
echo "Done.  Press enter to continue."
read

echo "Relocating horde cli programs"
mkdir ~iworx/lib/horde/bin
mv /usr/bin/horde-* ~iworx/lib/horde/bin/

echo "Patching horde-db-migrate"
cd ~iworx/
cat <<'EOF' | patch -p1
diff --git b/lib/horde/bin/horde-db-migrate a/lib/horde/bin/horde-db-migrate
index a67c7bb..0f2cf1d 100755
--- b/lib/horde/bin/horde-db-migrate
+++ a/lib/horde/bin/horde-db-migrate
@@ -1,4 +1,4 @@
-#!/usr/bin/php
+#!/home/interworx/bin/php
 <?php
 /**
  * Database migration script.
@@ -19,7 +19,7 @@
  * @license  http://www.horde.org/licenses/lgpl LGPL-2
  * @package  Horde
  */
-
+#require_once '/home/interworx/include/iworx.conf.php';
 $baseFile = __DIR__ . '/../lib/Application.php';
 if (file_exists($baseFile)) {
     require_once $baseFile;
EOF
echo "Done.  Press enter to continue."
read

echo "Copying over sam"
cd ~iworx/lib/horde_old/
tar -c sam | (cd ../horde/; tar -x)
[[ -f ~iworx/lib/horde/sam/SAM.php ]] && mv ~iworx/lib/horde/sam/SAM.php ~iworx/lib/horde/sam/Sam.php
echo "Done.  Press enter to continue."
read

echo "Copying over Interworx vacation driver"
cd ~iworx/lib/horde_old/
find . -name '*nterworx*' | xargs tar -c | (cd ../horde/; tar -xv)
echo "Done.  Press enter to continue."
read

echo "Changing default app to imp"
cd ~iworx/
cat <<'EOF' | patch -p1
diff --git b/lib/horde/config/prefs.php a/lib/horde/config/prefs.php
index 6e80a4c..eb06b14 100644
--- b/lib/horde/config/prefs.php
+++ a/lib/horde/config/prefs.php
@@ -542,7 +542,7 @@ $prefGroups['display'] = array(
 );

 $_prefs['initial_application'] = array(
-    'value' => 'horde',
+    'value' => 'imp',
     'type' => 'enum',
     'enum' => array(),
     'desc' => sprintf(_("What application should %s display after login?"), $GLOBALS['registry']->get('name')),
EOF
echo "Done.  Press enter to continue."
read

echo "Updating session cookie settings"
cd ~iworx/
cat <<'EOF' | patch -p1
diff --git a/lib/pear/Horde/Session.php b/lib/pear/Horde/Session.php
index a54d2561bc..dc3f7c566b 100644
--- a/lib/pear/Horde/Session.php
+++ b/lib/pear/Horde/Session.php
@@ -167,11 +167,16 @@ class Horde_Session
             ini_set('session.gc_maxlifetime', $conf['session']['timeout']);
         }

+        $use_ssl = $conf['use_ssl'];
+        if ($GLOBALS['browser']->usingSSLConnection()) {
+            $use_ssl = 1;
+        }
+
         session_set_cookie_params(
             $conf['session']['timeout'],
             $conf['cookie']['path'],
             $conf['cookie']['domain'],
-            $conf['use_ssl'] == 1 ? 1 : 0,
+            $use_ssl,
             true
         );
         session_cache_limiter(is_null($cache_limiter) ? $conf['session']['cache_limiter'] : $cache_limiter);
EOF

echo "Deleting ~iworx/lib/pear/test and ~iworx/lib/pear/doc"
rm -rf ~iworx/lib/pear/test
rm -rf ~iworx/lib/pear/doc
echo "Done.  Press enter to continue."
read

echo "Installing ~iworx/etc/pear.conf"
echo 'a:29:{s:9:"cache_dir";s:19:"/var/cache/php-pear";s:15:"default_channel";s:12:"pear.php.net";s:16:"preferred_mirror";s:12:"pear.php.net";s:13:"remote_config";s:0:"";s:13:"auto_discover";i:0;s:13:"master_server";s:12:"pear.php.net";s:7:"php_dir";s:29:"/usr/local/interworx/lib/pear";s:7:"doc_dir";s:33:"/usr/local/interworx/lib/pear/doc";s:7:"bin_dir";s:34:"/usr/local/interworx/lib/horde/bin";s:8:"data_dir";s:34:"/usr/local/interworx/lib/pear/data";s:7:"cfg_dir";s:9:"/etc/pear";s:7:"www_dir";s:13:"/var/www/html";s:8:"test_dir";s:34:"/usr/local/interworx/lib/pear/test";s:8:"temp_dir";s:8:"/var/tmp";s:12:"download_dir";s:18:"/tmp/pear/download";s:7:"php_bin";s:28:"/usr/local/interworx/bin/php";s:10:"php_prefix";s:0:"";s:10:"php_suffix";s:0:"";s:7:"php_ini";s:0:"";s:8:"username";s:0:"";s:8:"password";s:0:"";s:7:"verbose";i:1;s:15:"preferred_state";s:6:"stable";s:5:"umask";i:18;s:9:"cache_ttl";i:3600;s:8:"sig_type";s:3:"gpg";s:7:"sig_bin";s:12:"/usr/bin/gpg";s:9:"sig_keyid";s:0:"";s:10:"sig_keydir";s:13:"/etc/pearkeys";}' > ~iworx/etc/pear.conf
echo "Done.  Press enter to continue. ABOUT TO TRY ~iworx/bin/php horde-db-migrate -c ~iworx/etc/pear.conf"
read

echo "Running horde-db-migrate"
cd ~iworx/lib/horde/bin/
~iworx/bin/php horde-db-migrate -c ~iworx/etc/pear.conf
echo "Done.  Press enter to continue."
read

echo "Running horde-db-migrate again"
cd ~iworx/lib/horde/bin/
~iworx/bin/php horde-db-migrate -c ~iworx/etc/pear.conf
echo "Done.  Press enter to continue."
read

echo "Creating initial iworx_horde.sql"
~iworx/mysql/bin/mysqldump -u iworx_horde -p$(grep iworx_horde ~iworx/iworx.ini | sed 's/:/ /g' | sed 's/@/ /g' | awk '{print $3}') iworx_horde > ~iworx/sql/iworx_horde.sql
echo "Done.  Press enter to continue."
read

echo "Running cvspermsfix."
~iworx/bin/cvspermsfix.pex
echo "Done.  Press enter to continue."
read
